from os import popen
from getsys import get_platform

# command structure: [count total packages, count standalones, count dependencies, count orphans]
commands_list = {
    'archlinux': ['pacman', 'pacman -Q', 'pacman -Qe', 'command unavailable', 'pacman -Qtdq'],
    'debian': ['dpkg', 'a', 'b', 'c', 'd']
}

def get_commands():
    return commands_list.get('archlinux')

commands = get_commands()

def get_packages():
    return str(len(popen(get_commands()[1]).read().splitlines()))

def get_standalones():
    return str(len(popen(get_commands()[2]).read().splitlines()))

def get_dependencies():
    return str(len(popen(get_commands()[1]).read().splitlines()) - len(popen(get_commands()[2]).read().splitlines()))

def get_orphans():
    return str(len(popen(get_commands()[4]).read().splitlines()))


import os
from list import get_commands, get_packages, get_standalones, get_dependencies, get_orphans
from interface import banner, footer

def main():
    commands = get_commands()

    # Print the banner
    print(banner())

    # Print the package manager name
    print('-=-=- ' + commands[0] + ' -=-=-')
    print('You have ' + get_packages() + ' total packages. (' + commands[1] + ')')
    print('You have ' + get_standalones() + ' standalone packages. (' + commands[2] + ')')
    print('You have ' + get_dependencies() + ' dependencies. (' + commands[3] + ')')
    print('You have ' + get_orphans() + ' orphaned packages. (' + commands[4] + ')')
    
    print(footer())

main()


from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='whiteboard-bin',
    version='0.0.1',
    description='A lightweight package information utility. ',
    long_description=readme,
    author='Garrett Howard',
    author_email='garrett@mersh.com',
    url='https://github.com/howardjs/whiteboard',
    license=license,
    packages=find_packages(exclude=('tests', 'docs'))
)


import colors

def banner():
    return(colors.cyan + '\n-=-=-=-=-=- Whiteboard -=-=-=-=-=-\n' + colors.white)
    
def footer():
    return(colors.cyan + '\n-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-\n' + colors.white)


from sys import platform

def get_platform():
    if platform == 'linux':
        os_name = open('/etc/os-release').readlines()[0]
        if os_name.__contains__('Arch Linux'):
            return 'archlinux'
        else:
            print("Your Linux distribution is not supported.")
    else:
        return 'This program is currently only available for Linux systems.'